@@ -1,4 +1,4 @@
-"""Falcon Report Executions API Interface Class
+"""Falcon Report Executions API Interface Class.
 
  _______                        __ _______ __        __ __
 |   _   .----.-----.--.--.--.--|  |   _   |  |_.----|__|  |--.-----.
@@ -36,12 +36,13 @@ OTHER DEALINGS IN THE SOFTWARE.
 For more information, please refer to <https://unlicense.org>
 """
 from ._util import force_default, process_service_request, handle_single_argument
+from ._payload import reports_payload
 from ._service_class import ServiceClass
 from ._endpoint._report_executions import _report_executions_endpoints as Endpoints
 
 
 class ReportExecutions(ServiceClass):
-    """The only requirement to instantiate an instance of this class is one of the following:
+    """The only requirement to instantiate an instance of this class is one of the following.
 
     - a valid client_id and client_secret provided as keywords.
     - a credential dictionary with client_id and client_secret containing valid API credentials
@@ -52,9 +53,10 @@ class ReportExecutions(ServiceClass):
     - a previously-authenticated instance of the authentication service class (oauth2.py)
     - a valid token provided by the authentication service class (oauth2.py)
     """
+
     @force_default(defaults=["parameters"], default_types=["dict"])
     def get_download(self: object, *args, parameters: dict = None, **kwargs) -> dict:
-        """Get report entity download
+        """Get report entity download.
 
         Keyword arguments:
         ids -- ID of the report entity to retrieve.
@@ -78,6 +80,39 @@ class ReportExecutions(ServiceClass):
             params=handle_single_argument(args, parameters, "ids")
             )
 
+    @force_default(defaults=["body"], default_types=["dict"])
+    def retry_reports(self: object, *args, body: dict = None, **kwargs) -> dict:
+        """Retries a report execution.
+
+        Keyword arguments:
+        body -- full body payload, not required if keywords are used.
+                [
+                    {
+                        "id": "string"
+                    }
+                ]
+        ids -- ID of the report to re-attempt execution. String or list of strings.
+
+        Arguments: When not specified, the first argument to this method is assumed to be 'ids'.
+                   All others are ignored.
+
+        Returns: dict object containing API response.
+
+        HTTP Method: POST
+
+        Swagger URL
+        https://assets.falcon.crowdstrike.com/support/api/swagger.html#/report-executions/report-executions.retry
+        """
+        if not body:
+            body = reports_payload(passed_arguments=args, passed_keywords=kwargs)
+
+        return process_service_request(
+            calling_object=self,
+            endpoints=Endpoints,
+            operation_id="report_executions_retry",
+            body=body
+            )
+
     @force_default(defaults=["parameters"], default_types=["dict"])
     def get_reports(self: object, *args, parameters: dict = None, **kwargs) -> dict:
         """Retrieve report details for the provided report IDs.
@@ -106,7 +141,7 @@ class ReportExecutions(ServiceClass):
 
     @force_default(defaults=["parameters"], default_types=["dict"])
     def query_reports(self: object, parameters: dict = None, **kwargs) -> dict:
-        """Find all report execution IDs matching the query with filter
+        """Find all report execution IDs matching the query with filter.
 
         Keyword arguments:
         filter -- FQL query specifying the filter parameters.
@@ -140,4 +175,5 @@ class ReportExecutions(ServiceClass):
     # API and are defined here for ease of use purposes
     report_executions_download_get = get_download
     report_executions_get = get_reports
-    scheduled_reports_query = query_reports
+    reports_executions_query = query_reports
+    report_executions_retry = retry_reports
